==> tag_1.0.0.zip: server/src/main/java/cn/com/qmth/scancloud/client/MarkingcloudApiClient.java <==
package cn.com.qmth.scancloud.client;

import java.util.List;

import com.qmth.boot.core.retrofit.annotatioin.RetrofitClient;
import com.qmth.boot.core.retrofit.utils.SignatureInfo;

import cn.com.qmth.scancloud.enums.CardSource;
import cn.com.qmth.scancloud.model.AnswerCardInfo;
import cn.com.qmth.scancloud.model.DataUploadDto;
import cn.com.qmth.scancloud.model.DataUploadResponse;
import cn.com.qmth.scancloud.model.ExamInfoDto;
import cn.com.qmth.scancloud.model.FileUploadResponse;
import cn.com.qmth.scancloud.model.StudentInfo;
import cn.com.qmth.scancloud.model.UserInfo;
import okhttp3.MultipartBody;
import retrofit2.http.Body;
import retrofit2.http.Field;
import retrofit2.http.FormUrlEncoded;
import retrofit2.http.Header;
import retrofit2.http.Multipart;
import retrofit2.http.POST;
import retrofit2.http.Part;
import retrofit2.http.Path;
import retrofit2.http.Query;

@RetrofitClient(configuration = MarkingcloudApiConfiguration.class)
public interface MarkingcloudApiClient {

    @FormUrlEncoded
    @POST("card/answer/query")
    List<AnswerCardInfo> getAnswerCardInfo(@Header(SignatureInfo.HEADER_NAME) String signatureInfo,
            @Field("examId") Long examId, @Field("number") Integer number);

    @FormUrlEncoded
    @POST("card/answer/delete")
    String deleteAnswerCard(@Header(SignatureInfo.HEADER_NAME) String signatureInfo, @Field("examId") Long examId,
            @Field("number") Integer number);

    @Multipart
    @POST("card/answer/save")
    AnswerCardInfo saveAnswerCard(@Header(SignatureInfo.HEADER_NAME) String signatureInfo, @Query("examId") Long examId,
            @Query("number") Integer number, @Query("source") CardSource source,
            @Query("subjectCode") String subjectCode, @Query("parameter") String parameter,
            @Query("remark") String remark, @Query("paperCount") Integer paperCount,
            @Query("singlePage") Boolean singlePage, @Query("needAdapte") Boolean needAdapte, @Query("md5") String md5,
            @Part MultipartBody.Part file);

    @Multipart
    @POST("file/sheet/upload")
    FileUploadResponse sheetFileUpload(@Header(SignatureInfo.HEADER_NAME) String signatureInfo,
            @Query("examId") Long examId, @Query("examNumber") String examNumber, @Query("index") Integer index,
            @Query("md5") String md5, @Part MultipartBody.Part file);

    @Multipart
    @POST("file/slice/upload")
    FileUploadResponse sliceFileUpload(@Header(SignatureInfo.HEADER_NAME) String signatureInfo,
            @Query("examId") Long examId, @Query("examNumber") String examNumber, @Query("index") Integer index,
            @Query("md5") String md5, @Part MultipartBody.Part file);

//    @FormUrlEncoded
//    @POST("scan/student/{examId}")
//    DataUploadResponse dataUpload(@Header(SignatureInfo.HEADER_NAME) String signatureInfo, @Path("examId") Long examId,
//            @Field("examNumber") String examNumber, @Field("sliceCount") Integer sliceCount,
//            @Field("sheetCount") Integer sheetCount, @Field("answers") String answers, @Field("absent") Boolean absent,
//            @Field("batchCode") String batchCode, @Field("paperType") String paperType,
//            @Field("manual") Boolean manual);
    
    @POST("scan/student/{examId}")
    List<DataUploadResponse> dataUpload(@Header(SignatureInfo.HEADER_NAME) String signatureInfo, @Path("examId") Long examId,
    		@Body List<DataUploadDto> scStudentParameter);

    @FormUrlEncoded
    @POST("admin/login")
    UserInfo login(@Field("loginName") String loginName, @Field("password") String password);

    @FormUrlEncoded
    @POST("exam/query")
    List<ExamInfoDto> examQuery(@Header(SignatureInfo.HEADER_NAME) String signatureInfo,
            @Field("pageNumber") long pageNumber, @Field("pageSize") long pageSize);

    @FormUrlEncoded
    @POST("exam/config/save")
    ExamInfoDto examConfig(@Header(SignatureInfo.HEADER_NAME) String signatureInfo, @Field("examId") Long examId,
            @Field("config") String config);

    @FormUrlEncoded
    @POST("exam/students/count")
    long studentCount(@Header(SignatureInfo.HEADER_NAME) String signatureInfo, @Field("examId") Long examId);

    @FormUrlEncoded
    @POST("exam/students")
    List<StudentInfo> getStudents(@Header(SignatureInfo.HEADER_NAME) String signatureInfo, @Field("examId") Long examId,
            @Field("pageNumber") int pageNumber, @Field("pageSize") int pageSize);
    
}

==> tag_1.0.2.zip: server/src/main/java/cn/com/qmth/scancloud/client/MarkingcloudApiClient.java <==
package cn.com.qmth.scancloud.client;

import cn.com.qmth.scancloud.entity.QuestionEntity;
import cn.com.qmth.scancloud.enums.CardSource;
import cn.com.qmth.scancloud.model.*;
import com.qmth.boot.core.retrofit.annotatioin.RetrofitClient;
import com.qmth.boot.core.retrofit.utils.SignatureInfo;
import okhttp3.MultipartBody;
import retrofit2.http.*;

import java.util.List;

@RetrofitClient(configuration = MarkingcloudApiConfiguration.class)
public interface MarkingcloudApiClient {

    @FormUrlEncoded
    @POST("card/answer/query")
    List<AnswerCardInfo> getAnswerCardInfo(@Header(SignatureInfo.HEADER_NAME) String signatureInfo,
            @Field("examId") Long examId, @Field("number") Integer number);

    @FormUrlEncoded
    @POST("card/answer/delete")
    String deleteAnswerCard(@Header(SignatureInfo.HEADER_NAME) String signatureInfo, @Field("examId") Long examId,
            @Field("number") Integer number);

    @Multipart
    @POST("card/answer/save")
    AnswerCardInfo saveAnswerCard(@Header(SignatureInfo.HEADER_NAME) String signatureInfo, @Query("examId") Long examId,
            @Query("number") Integer number, @Query("source") CardSource source,
            @Query("subjectCode") String subjectCode, @Query("parameter") String parameter,
            @Query("remark") String remark, @Query("paperCount") Integer paperCount,
            @Query("singlePage") Boolean singlePage, @Query("needAdapte") Boolean needAdapte,
            @Query("sliceConfig") String sliceConfig, @Query("md5") String md5, @Part MultipartBody.Part file);

    @Multipart
    @POST("file/sheet/upload")
    FileUploadResponse sheetFileUpload(@Header(SignatureInfo.HEADER_NAME) String signatureInfo,
            @Query("examId") Long examId, @Query("examNumber") String examNumber, @Query("index") Integer index,
            @Query("md5") String md5, @Part MultipartBody.Part file);

    @Multipart
    @POST("file/slice/upload")
    FileUploadResponse sliceFileUpload(@Header(SignatureInfo.HEADER_NAME) String signatureInfo,
            @Query("examId") Long examId, @Query("examNumber") String examNumber, @Query("index") Integer index,
            @Query("md5") String md5, @Part MultipartBody.Part file);
    
    @Multipart
    @POST("file/paper/upload")
    FileUploadResponse paperFileUpload(@Header(SignatureInfo.HEADER_NAME) String signatureInfo,
            @Query("examId") Long examId, @Query("subjectCode") String subjectCode, @Query("format") String format,
            @Query("md5") String md5, @Part MultipartBody.Part file);
    
    @Multipart
    @POST("file/answer/upload")
    FileUploadResponse answerFileUpload(@Header(SignatureInfo.HEADER_NAME) String signatureInfo,
            @Query("examId") Long examId, @Query("subjectCode") String subjectCode, @Query("format") String format,
            @Query("md5") String md5, @Part MultipartBody.Part file);

    //    @FormUrlEncoded
    //    @POST("scan/student/{examId}")
    //    DataUploadResponse dataUpload(@Header(SignatureInfo.HEADER_NAME) String signatureInfo, @Path("examId") Long examId,
    //            @Field("examNumber") String examNumber, @Field("sliceCount") Integer sliceCount,
    //            @Field("sheetCount") Integer sheetCount, @Field("answers") String answers, @Field("absent") Boolean absent,
    //            @Field("batchCode") String batchCode, @Field("paperType") String paperType,
    //            @Field("manual") Boolean manual);

    @POST("scan/student/{examId}")
    List<DataUploadResponse> dataUpload(@Header(SignatureInfo.HEADER_NAME) String signatureInfo,
            @Path("examId") Long examId, @Body List<DataUploadDto> scStudentParameter);

    @FormUrlEncoded
    @POST("admin/login")
    UserInfo login(@Field("loginName") String loginName, @Field("password") String password);

    @FormUrlEncoded
    @POST("exam/query")
    List<ExamInfoDto> examQuery(@Header(SignatureInfo.HEADER_NAME) String signatureInfo,
            @Field("pageNumber") long pageNumber, @Field("pageSize") long pageSize);

    @FormUrlEncoded
    @POST("exam/config/save")
    ExamInfoDto examConfig(@Header(SignatureInfo.HEADER_NAME) String signatureInfo, @Field("examId") Long examId,
            @Field("config") String config);

    @FormUrlEncoded
    @POST("exam/students/count")
    long studentCount(@Header(SignatureInfo.HEADER_NAME) String signatureInfo, @Field("examId") Long examId);

    @FormUrlEncoded
    @POST("exam/students")
    List<StudentInfo> getStudents(@Header(SignatureInfo.HEADER_NAME) String signatureInfo, @Field("examId") Long examId,
            @Field("pageNumber") int pageNumber, @Field("pageSize") int pageSize);

    @POST("scan/student/delete")
    String studentFileDelete(@Header(SignatureInfo.HEADER_NAME) String signatureInfo, @Query("examId") Long examId,
            @Query("examNumber") String examNumber);

    @FormUrlEncoded
    @POST("exam/question/list")
    List<QuestionEntity> getQuestion(@Header(SignatureInfo.HEADER_NAME) String signatureInfo,
            @Field("examId") Long examId, @Field("subjectCode") String subjectCode);

}
